@@ -24,8 +24,8 @@ class LineProfiler(Viewer):
     _model_name = Unicode('LineProfilerModel').tag(sync=True)
     _view_module = Unicode('itk-jupyter-widgets').tag(sync=True)
     _model_module = Unicode('itk-jupyter-widgets').tag(sync=True)
-    _view_module_version = Unicode('^0.16.2').tag(sync=True)
-    _model_module_version = Unicode('^0.16.2').tag(sync=True)
+    _view_module_version = Unicode('^0.16.3').tag(sync=True)
+    _model_module_version = Unicode('^0.16.3').tag(sync=True)
     point1 = NDArray(dtype=np.float64, default_value=np.zeros((3,), dtype=np.float64),
                 help="First point in physical space that defines the line profile")\
             .tag(sync=True, **array_serialization)\
@@ -101,7 +101,7 @@ def line_profile(image, order=2, plotter=None, comparisons=None, **viewer_kwargs
             image_ = image_from_array
         else:
             image_ = image_or_array
-        image_array = itk.GetArrayViewFromImage(image_)
+        image_array = itk.array_view_from_image(image_)
         dimension = image_.GetImageDimension()
         distance = np.sqrt(sum([(profiler.point1[ii] - profiler.point2[ii])**2 for ii in range(dimension)]))
         index1 = tuple(image_.TransformPhysicalPointToIndex(tuple(profiler.point1[:dimension])))
